<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sq">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="94"/>
        <source>MX Package Installer</source>
        <translation>Instalues Paketash MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Popular Applications</source>
        <translation>Aplikacione Popullore</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <location filename="../mainwindow.cpp" line="97"/>
        <source>Package</source>
        <translation>Paketë</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <location filename="../mainwindow.cpp" line="97"/>
        <source>Info</source>
        <translation>Hollësi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <location filename="../mainwindow.ui" line="250"/>
        <location filename="../mainwindow.ui" line="657"/>
        <location filename="../mainwindow.ui" line="986"/>
        <location filename="../mainwindow.cpp" line="97"/>
        <source>Description</source>
        <translation>Përshkrim</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <location filename="../mainwindow.ui" line="216"/>
        <location filename="../mainwindow.ui" line="623"/>
        <location filename="../mainwindow.ui" line="955"/>
        <location filename="../mainwindow.ui" line="1235"/>
        <source>search</source>
        <translation>kërko</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="123"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Greyed out items have already been installed.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Administroni paketa popullore&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Zërat e treguar në gri janë të instaluar tashmë.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="153"/>
        <source>Stable Repo</source>
        <translation>Depo e Të qëndrueshmit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="174"/>
        <location filename="../mainwindow.ui" line="568"/>
        <location filename="../mainwindow.ui" line="900"/>
        <location filename="../mainwindow.ui" line="1178"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter packages according to their status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filtrojini paketat sipas gjendjes së tyre.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="177"/>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="571"/>
        <location filename="../mainwindow.ui" line="575"/>
        <location filename="../mainwindow.ui" line="903"/>
        <location filename="../mainwindow.ui" line="907"/>
        <location filename="../mainwindow.cpp" line="2513"/>
        <source>All packages</source>
        <translation>Krejt paketat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <location filename="../mainwindow.ui" line="580"/>
        <location filename="../mainwindow.ui" line="912"/>
        <location filename="../mainwindow.cpp" line="2526"/>
        <source>Installed</source>
        <translation>Të instaluara</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <location filename="../mainwindow.ui" line="585"/>
        <location filename="../mainwindow.ui" line="917"/>
        <location filename="../mainwindow.cpp" line="2524"/>
        <source>Upgradable</source>
        <translation>Të përmirësueshme</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="196"/>
        <location filename="../mainwindow.ui" line="590"/>
        <location filename="../mainwindow.ui" line="922"/>
        <location filename="../mainwindow.ui" line="1215"/>
        <location filename="../mainwindow.cpp" line="2498"/>
        <location filename="../mainwindow.cpp" line="2528"/>
        <location filename="../mainwindow.cpp" line="2619"/>
        <location filename="../mainwindow.cpp" line="2620"/>
        <source>Not installed</source>
        <translation>Jo të instaluara</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="240"/>
        <location filename="../mainwindow.ui" line="647"/>
        <location filename="../mainwindow.ui" line="976"/>
        <source>Package Name</source>
        <translation>Emër Pakete</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <location filename="../mainwindow.ui" line="652"/>
        <location filename="../mainwindow.ui" line="981"/>
        <location filename="../mainwindow.ui" line="1270"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <location filename="../mainwindow.ui" line="684"/>
        <location filename="../mainwindow.ui" line="1043"/>
        <source>Total packages:</source>
        <translation>Paketa gjithsej:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="291"/>
        <location filename="../mainwindow.ui" line="698"/>
        <location filename="../mainwindow.ui" line="1050"/>
        <source>Hide library and developer packages</source>
        <translation>Fshih bibliotekë dhe paketa zhvilluesi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="313"/>
        <location filename="../mainwindow.ui" line="720"/>
        <location filename="../mainwindow.ui" line="1102"/>
        <source>Refresh list</source>
        <translation>Rifresko listën</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="327"/>
        <location filename="../mainwindow.ui" line="734"/>
        <location filename="../mainwindow.ui" line="1022"/>
        <source>Installed:</source>
        <translation>Të instaluara:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="357"/>
        <location filename="../mainwindow.ui" line="764"/>
        <location filename="../mainwindow.ui" line="1015"/>
        <source>Upgradable:</source>
        <translation>Të përmirësueshme:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="387"/>
        <location filename="../mainwindow.ui" line="791"/>
        <location filename="../mainwindow.ui" line="1083"/>
        <source>Also Install &quot;Recommended&quot; Packages</source>
        <translation>Instalo gjithashtu paketa “Të rekomanduara”</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="394"/>
        <source>Remove orphan packages</source>
        <translation>Hiqi paketat jetime</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="404"/>
        <location filename="../mainwindow.ui" line="1340"/>
        <source>Upgrade All</source>
        <translation>Përmirësoji Krejt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <location filename="../mainwindow.ui" line="598"/>
        <location filename="../mainwindow.ui" line="930"/>
        <location filename="../mainwindow.ui" line="1497"/>
        <source>Greyed out items have already been installed.</source>
        <translation>Zërat e treguar në gri janë të instaluar tashmë.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="477"/>
        <location filename="../mainwindow.ui" line="540"/>
        <location filename="../mainwindow.ui" line="867"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;= Upgradable package. Newer version available in selected repository.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;= Paketë e përmirësueshme. Versione të gatshëm më të rinj te depoja e përzgjedhur.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>MX Test Repo</source>
        <translation>Depo MX Test</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="824"/>
        <source>Debian Backports</source>
        <translation>Backport-a Debian</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1157"/>
        <source>Flatpaks</source>
        <translation>Paketime Flatpak</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1181"/>
        <location filename="../mainwindow.ui" line="1185"/>
        <location filename="../mainwindow.cpp" line="2480"/>
        <source>All apps</source>
        <translation>Krejt aplikacionet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1190"/>
        <location filename="../mainwindow.cpp" line="2484"/>
        <source>All runtimes</source>
        <translation>Krejt runtime-et</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1195"/>
        <location filename="../mainwindow.cpp" line="2488"/>
        <source>All available</source>
        <translation>Krejt të gatshmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1200"/>
        <location filename="../mainwindow.cpp" line="2478"/>
        <source>Installed apps</source>
        <translation>Aplikacione të instaluara</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1205"/>
        <location filename="../mainwindow.cpp" line="2476"/>
        <source>Installed runtimes</source>
        <translation>Runtime-e të instaluar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1210"/>
        <location filename="../mainwindow.cpp" line="2496"/>
        <location filename="../mainwindow.cpp" line="2613"/>
        <location filename="../mainwindow.cpp" line="2614"/>
        <source>All installed</source>
        <translation>Krejt të instaluarat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1260"/>
        <source>Short Name</source>
        <translation>Emër i Shkurtër</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1265"/>
        <source>Full Package Name</source>
        <translation>Emër i Plotë Pakete</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1275"/>
        <source>Size</source>
        <translation>Madhësi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1319"/>
        <source>Total items </source>
        <translation>Objekte gjithsej </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1333"/>
        <source>Installed apps:</source>
        <translation>Aplikacione të instaluara:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1386"/>
        <source>Advanced</source>
        <translation>Të mëtejshme</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1416"/>
        <source>Total installed size:</source>
        <translation>Madhësi të instaluarash gjithsej:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1430"/>
        <source>Remove unused runtimes</source>
        <translation>Hiqi runtime-et e papërdorur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1447"/>
        <location filename="../mainwindow.ui" line="1451"/>
        <source>For all users</source>
        <translation>Për krejt përdoruesit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1456"/>
        <source>For current user</source>
        <translation>Për përdoruesin e tanishëm</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1474"/>
        <source>Remote (repo):</source>
        <translation>E largët (depo):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1517"/>
        <location filename="../mainwindow.cpp" line="2302"/>
        <location filename="../mainwindow.cpp" line="2436"/>
        <source>Console Output</source>
        <translation>Ç’jep Konsola</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1523"/>
        <source>Enter</source>
        <translation>Tasti Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1534"/>
        <source>Respond here, or just press Enter</source>
        <translation>Përgjigjuni këtu, ose thjesht shtypni tastin Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1590"/>
        <source>Uninstall</source>
        <translation>Çinstaloje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1597"/>
        <source>Alt+U</source>
        <translation>Alt+Ç</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1613"/>
        <source>About this application</source>
        <translation>Mbi këtë aplikacion</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1616"/>
        <source>About...</source>
        <translation>Mbi…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1623"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1671"/>
        <source>Display help </source>
        <translation>Shfaq ndihmën </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1674"/>
        <source>Help</source>
        <translation>Ndihmë</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1681"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1697"/>
        <location filename="../mainwindow.cpp" line="1072"/>
        <location filename="../mainwindow.cpp" line="2606"/>
        <location filename="../mainwindow.cpp" line="2610"/>
        <location filename="../mainwindow.cpp" line="2865"/>
        <source>Install</source>
        <translation>Instaloje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1704"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1723"/>
        <source>Quit application</source>
        <translation>Dil nga aplikacioni</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1726"/>
        <source>Close</source>
        <translation>Mbylle</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1733"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="176"/>
        <source>Uninstalling packages...</source>
        <translation>Po çinstalohen paketa…</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="181"/>
        <source>Running pre-uninstall operations...</source>
        <translation>Po kryhen veprime para-çinstalimi…</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="196"/>
        <source>Running post-uninstall operations...</source>
        <translation>Po kryhen veprime pas-çinstalimi…</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>Refreshing sources...</source>
        <translation>Po rifreskohen burime…</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="226"/>
        <location filename="../mainwindow.cpp" line="1120"/>
        <location filename="../mainwindow.cpp" line="1249"/>
        <location filename="../mainwindow.cpp" line="1387"/>
        <location filename="../mainwindow.cpp" line="1449"/>
        <location filename="../mainwindow.cpp" line="2120"/>
        <location filename="../mainwindow.cpp" line="2150"/>
        <location filename="../mainwindow.cpp" line="2162"/>
        <location filename="../mainwindow.cpp" line="2275"/>
        <location filename="../mainwindow.cpp" line="2294"/>
        <location filename="../mainwindow.cpp" line="2689"/>
        <location filename="../mainwindow.cpp" line="2765"/>
        <location filename="../mainwindow.cpp" line="2795"/>
        <location filename="../mainwindow.cpp" line="2888"/>
        <location filename="../mainwindow.cpp" line="2912"/>
        <source>Error</source>
        <translation>Gabim</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="227"/>
        <source>There was a problem updating sources. Some sources may not have provided updates. For more info check: </source>
        <translation>Pati një problem me përditësimin e burimeve. Disa burime mund të mos kenë dhënë përditësime. Për më tepër hollësi, shihni: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="619"/>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="626"/>
        <source>Please wait...</source>
        <translation>Ju lutemi, pritni…</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="810"/>
        <location filename="../mainwindow.cpp" line="829"/>
        <source>Version </source>
        <translation>Version </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="810"/>
        <source> in stable repo</source>
        <translation> në depon e të qëndrueshmit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="812"/>
        <source>Not available in stable repo</source>
        <translation>Jo i passhëm në depon e të qëndrueshmit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="821"/>
        <location filename="../mainwindow.cpp" line="2413"/>
        <source>Latest version </source>
        <translation>Versioni më i ri </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="821"/>
        <location filename="../mainwindow.cpp" line="2413"/>
        <source> already installed</source>
        <translation> tashmë i instaluar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="829"/>
        <source> installed</source>
        <translation> i instaluar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="940"/>
        <source>You are about to use the MX Test repository, whose packages are provided for testing purposes only. It is possible that they might break your system, so it is suggested that you back up your system and install or update only one package at a time. Please provide feedback in the Forum so the package can be evaluated before moving up to Main.</source>
        <translation>Ju ndan një hap nga përdorimi i depos MX Test, paketat e së cilës jepen vetëm për qëllime testimi. Është e mundur që të dëmtojnë sistemin, ndaj sugjerohet që të kopjeruani sistemin dhe të instaloni apo përditësoni vetëm një paketë në herë. Ju lutemi, jepni përshtypjet te Forumi, që kështu paketa të mund të vlerësohet, përpara se të kalojë te Kryesori.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="949"/>
        <source>You are about to use Debian Backports, which contains packages taken from the next Debian release (called &apos;testing&apos;), adjusted and recompiled for usage on Debian stable. They cannot be tested as extensively as in the stable releases of Debian and MX Linux, and are provided on an as-is basis, with risk of incompatibilities with other components in Debian stable. Use with care!</source>
        <translation>Ju ndan një hap nga përdorimi i depos Debian Backports, që përmban paketa të marra nga hedhja e ardhshme në qarkullim e Debian-it (e quajtur “testim”), përshtatur dhe ripërpiluar për përdorim në versionin e qëndrueshëm të Debian-it. S’mund të testohen aq gjerë sa te hedhjet në qarkullim të versioneve të qëndrueshëm të Debian-it dhe të MX Linux-it dhe jepen ashtu siç janë, me rrezikun e mospërputhjes me përbërës të tjerë te versioni i qëndrueshëm i Debian-it. Përdorini me kujdes!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="957"/>
        <source>MX Linux includes this repository of flatpaks for the users&apos; convenience only, and is not responsible for the functionality of the individual flatpaks themselves. For more, consult flatpaks in the Wiki.</source>
        <translation>MX Linux e përfshin këtë depo paketash Flatpak vetëm për leverdinë e përdoruesve dhe nuk është përgjegjës për punimin e vetë paketave Flatpak. Për më tepër, shihni rreth paketimesh Flatpak te Wiki.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="964"/>
        <location filename="../mainwindow.cpp" line="2898"/>
        <source>Warning</source>
        <translation>Kujdes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="968"/>
        <source>Do not show this message again</source>
        <translation>Mos e shfaq sërish këtë mesazh</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1070"/>
        <source>Remove</source>
        <translation>Hiqe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1084"/>
        <source>The following packages were selected. Click Show Details for list of changes.</source>
        <translation>Janë përzgjedhur paketat vijuese. Për një listë të ndryshimeve, klikoni mbi “Shfaq Hollësi”.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1121"/>
        <location filename="../mainwindow.cpp" line="1250"/>
        <location filename="../mainwindow.cpp" line="1450"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation>S’ka Internet, s’do të jetë në gjendje të shkarkojë listën e paketave</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1126"/>
        <source>Installing packages...</source>
        <translation>Po instalohen paketa…</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1183"/>
        <source>Post-processing...</source>
        <translation>Pas-përpunim…</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1213"/>
        <source>Pre-processing for </source>
        <translation>Para-përpunim për </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1226"/>
        <source>Installing </source>
        <translation>Po instalohet </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1233"/>
        <source>Post-processing for </source>
        <translation>Pas-përpunim për </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1388"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation>Pati një gabim në shkrim kartele: %1. Ju lutemi, kontrolloni nëse keni hapësirë të lirë të mjaftueshme në diskun tuaj</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1458"/>
        <source>Downloading package info...</source>
        <translation>Po shkarkohen hollësi pakete…</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1912"/>
        <location filename="../mainwindow.cpp" line="1989"/>
        <location filename="../mainwindow.cpp" line="2013"/>
        <source>Package info</source>
        <translation>Hollësi pakete</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1926"/>
        <location filename="../mainwindow.cpp" line="2831"/>
        <source>More &amp;info...</source>
        <translation>Më tepër &amp;hollësi…</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1955"/>
        <source>Packages to be installed: </source>
        <translation>Paketa për t’u instaluar: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2116"/>
        <location filename="../mainwindow.cpp" line="2129"/>
        <location filename="../mainwindow.cpp" line="2144"/>
        <location filename="../mainwindow.cpp" line="2159"/>
        <location filename="../mainwindow.cpp" line="2247"/>
        <location filename="../mainwindow.cpp" line="2270"/>
        <location filename="../mainwindow.cpp" line="2685"/>
        <location filename="../mainwindow.cpp" line="2759"/>
        <location filename="../mainwindow.cpp" line="2789"/>
        <location filename="../mainwindow.cpp" line="2882"/>
        <source>Done</source>
        <translation>U bë</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2116"/>
        <location filename="../mainwindow.cpp" line="2129"/>
        <location filename="../mainwindow.cpp" line="2144"/>
        <location filename="../mainwindow.cpp" line="2159"/>
        <location filename="../mainwindow.cpp" line="2247"/>
        <location filename="../mainwindow.cpp" line="2270"/>
        <location filename="../mainwindow.cpp" line="2288"/>
        <location filename="../mainwindow.cpp" line="2685"/>
        <location filename="../mainwindow.cpp" line="2759"/>
        <location filename="../mainwindow.cpp" line="2789"/>
        <location filename="../mainwindow.cpp" line="2882"/>
        <location filename="../mainwindow.cpp" line="2906"/>
        <source>Processing finished successfully.</source>
        <translation>Përpunimi përfundoi me sukses.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2121"/>
        <location filename="../mainwindow.cpp" line="2151"/>
        <location filename="../mainwindow.cpp" line="2163"/>
        <location filename="../mainwindow.cpp" line="2690"/>
        <location filename="../mainwindow.cpp" line="2766"/>
        <location filename="../mainwindow.cpp" line="2796"/>
        <source>Problem detected while installing, please inspect the console output.</source>
        <translation>U pikas problem teksa instalohej, ju lutemi, vëzhgoni ç’jepet te konsola.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2173"/>
        <source>About %1</source>
        <translation>Mbi %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2174"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2175"/>
        <source>Package Installer for MX Linux</source>
        <translation>Instalues Paketash për MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2177"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Të drejta kopjimi (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2178"/>
        <source>%1 License</source>
        <translation>Licencë %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2191"/>
        <source>%1 Help</source>
        <translation>Ndihmë për %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2275"/>
        <source>We encountered a problem uninstalling, please check output</source>
        <translation>Hasëm një problem me çinstalimin, ju lutemi, shihni ç’jepet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2288"/>
        <location filename="../mainwindow.cpp" line="2906"/>
        <source>Success</source>
        <translation>Sukses</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2294"/>
        <location filename="../mainwindow.cpp" line="2912"/>
        <source>We encountered a problem uninstalling the program</source>
        <translation>Hasëm një problem me çinstalimin e programit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2387"/>
        <location filename="../mainwindow.cpp" line="2399"/>
        <source>Flatpak not installed</source>
        <translation>Flatpak-u s’është i instaluar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2388"/>
        <source>Flatpak is not currently installed.
OK to go ahead and install it?</source>
        <translation>Flatpak-u aktualisht s’është i instaluar.
OK të ecet më tej dhe të instalohet?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2399"/>
        <source>Flatpak was not installed</source>
        <translation>Flatpak-u s’qe i instaluar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2423"/>
        <location filename="../mainwindow.cpp" line="2445"/>
        <source>Flathub remote failed</source>
        <translation>Dështoi lidhja me pjesën e largët Flathub</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2423"/>
        <location filename="../mainwindow.cpp" line="2445"/>
        <source>Flathub remote could not be added</source>
        <translation>S’u shtua dot pjesë e largët Flathub</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2431"/>
        <source>Needs re-login</source>
        <translation>Lyp rihyrje në llogari</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2432"/>
        <source>You might need to logout/login to see installed items in the menu</source>
        <translation>Mund t’ju duhet të dilni/hyni në llogari, që të shihni te menuja zërat e instaluar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2606"/>
        <source>Upgrade</source>
        <translation>Përmirësojeni</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2718"/>
        <source>Quit?</source>
        <translation>Të dilet?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2719"/>
        <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
        <translation>Proces ende në xhirim, dalja mund ta lërë sistemin në një gjendje të paqëndrueshme.&lt;p&gt;&lt;b&gt;Jeni i sigurt se doni të dilet nga Instaluesi MX i Paketave?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2863"/>
        <source>Reinstall</source>
        <translation>Riinstaloje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2889"/>
        <source>Problem detected during last operation, please inspect the console output.</source>
        <translation>U pikas problem gjatë veprimit të fundit, ju lutemi, vëzhgoni ç’jepet te konsola.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2899"/>
        <source>Potentially dangerous operation.
Please make sure you check carefully the list of packages to be removed.</source>
        <translation>Veprim potencialisht i rrezikshëm.
Ju lutemi, sigurohuni se kontrolluat me kujdes listën e paketave për heqje.</translation>
    </message>
</context>
<context>
    <name>ManageRemotes</name>
    <message>
        <location filename="../remotes.cpp" line="13"/>
        <source>Manage Flatpak Remotes</source>
        <translation>Administroni Pjesë të Largëta Flatpak</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="22"/>
        <source>For all users</source>
        <translation>Për krejt përdoruesit</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="23"/>
        <source>For current user</source>
        <translation>Për përdoruesin e tanishëm</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="29"/>
        <source>enter Flatpak remote URL</source>
        <translation>jepni URL pjese të largët Flatpak</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="32"/>
        <source>enter Flatpakref location to install app</source>
        <translation>jepni vendndodhje Flatpakref-i që të instalohet aplikacioni</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="34"/>
        <source>Add or remove flatpak remotes (repos), or install apps using flatpakref URL or path</source>
        <translation>Shtoni ose hiqni pjesë të largëta Flatpak (depo), ose instaloni aplikacione duke përdorur URL ose shteg flatpakref</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="43"/>
        <source>Remove remote</source>
        <translation>Hiqni pjesë të largët</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="48"/>
        <source>Add remote</source>
        <translation>Shtoni pjesë të largët</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="53"/>
        <source>Install app</source>
        <translation>Instaloje aplikacionin</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="58"/>
        <source>Close</source>
        <translation>Mbylle</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="75"/>
        <source>Not removable</source>
        <translation>Jo i heqshëm</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="76"/>
        <source>Flathub is the main Flatpak remote and won&apos;t be removed</source>
        <translation>Flathub është pjesa e largët kryesore Flatpak dhe s’do të hiqet</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="96"/>
        <source>Error adding remote</source>
        <translation>Gabim shtimi pjese të largët</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="97"/>
        <source>Could not add remote - command returned an error. Please double-check the remote address and try again</source>
        <translation>S’u shtua dot pjesë e largët - urdhri u përgjigj me një gabim. Ju lutemi, rikontrollojeni adresën e pjesës së largët dhe riprovoni</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="102"/>
        <source>Success</source>
        <translation>Sukses</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="102"/>
        <source>Remote added successfully</source>
        <translation>Pjesa e largët u shtua me sukses</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Licencë</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Regjistër ndryshimesh</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;Mbylle</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Error</source>
        <translation>Gabim</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Duket të keni hyrë si rrënjë, ju lutemi, që të përdorni këtë program, dilni dhe bëni hyrjen si përdorues normal.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="84"/>
        <source>Unable to get exclusive lock</source>
        <translation>S’arrihet të kihet kyçje ekskluzive</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="85"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>Është duke xhiruar një tjetër aplikacion administrimi paketash (bie fjala, Synaptic, ose apt-get). Ju lutemi, së pari, mbyllni atë aplikacion</translation>
    </message>
</context>
</TS>
